<?php

namespace Bayuaznu\Bayuazni\Policies;

use Litepie\User\Contracts\UserPolicy;
use Bayuaznu\Bayuazni\Models\Pasien;

class PasienPolicy
{

    /**
     * Determine if the given user can view the pasien.
     *
     * @param UserPolicy $user
     * @param Pasien $pasien
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pasien $pasien)
    {
        if ($user->canDo('bayuazni.pasien.view') && $user->isAdmin()) {
            return true;
        }

        return $pasien->user_id == user_id() && $pasien->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pasien.
     *
     * @param UserPolicy $user
     * @param Pasien $pasien
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('bayuazni.pasien.create');
    }

    /**
     * Determine if the given user can update the given pasien.
     *
     * @param UserPolicy $user
     * @param Pasien $pasien
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pasien $pasien)
    {
        if ($user->canDo('bayuazni.pasien.edit') && $user->isAdmin()) {
            return true;
        }

        return $pasien->user_id == user_id() && $pasien->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pasien.
     *
     * @param UserPolicy $user
     * @param Pasien $pasien
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pasien $pasien)
    {
        return $pasien->user_id == user_id() && $pasien->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pasien.
     *
     * @param UserPolicy $user
     * @param Pasien $pasien
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pasien $pasien)
    {
        if ($user->canDo('bayuazni.pasien.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pasien.
     *
     * @param UserPolicy $user
     * @param Pasien $pasien
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pasien $pasien)
    {
        if ($user->canDo('bayuazni.pasien.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
