<?php

namespace Bayuaznu\Bayuazni\Providers;

use Illuminate\Support\ServiceProvider;

class BayuazniServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'bayuazni');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'bayuazni');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerBayuazni();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerBayuazni()
    {
        $this->app->bind('bayuazni', function($app) {
            return new Bayuazni($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Bayuazni', 'Lavalite\Bayuazni\Facades\Bayuazni');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('bayuaznu.bayuazni', function ($app) {
            return $this->app->make('Bayuaznu\Bayuazni\Bayuazni');
        });

                // Bind Pasien to repository
        $this->app->bind(
            'Bayuaznu\Bayuazni\Interfaces\PasienRepositoryInterface',
            \Bayuaznu\Bayuazni\Repositories\Eloquent\PasienRepository::class
        );

        $this->app->register(\Bayuaznu\Bayuazni\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Bayuaznu\Bayuazni\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and bayuazni's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/bayuazni.php', 'bayuazni'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeBayuazni::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bayuaznu.bayuazni'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('bayuaznu/bayuazni.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/bayuazni')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/bayuazni')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
